@@ -1,5 +1,5 @@
 #
-# $Id: X509.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: X509.pm,v 166b8eca4d58 2015/01/19 07:05:47 gomor $
 #
 # crypto::x509 Brik
 #
@@ -11,10 +11,8 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
-      tags => [ qw(unstable openssl ssl pki certificate) ],
-      author => 'GomoR <GomoR[at]metabrik.org>',
-      license => 'http://opensource.org/licenses/BSD-3-Clause',
+      revision => '$Revision: 166b8eca4d58 $',
+      tags => [ qw(unstable crypto x509) ],
       attributes => {
          datadir => [ qw(directory) ],
          ca_name => [ qw(name) ],
@@ -24,21 +22,19 @@ sub brik_properties {
          ca_directory => [ qw(directory) ],
          ca_conf => [ qw(conf_file) ],
          use_passphrase => [ qw(0|1) ],
-         key_size => [ qw(bits) ],
       },
       attributes_default => {
          capture_stderr => 1,
          use_passphrase => 0,
-         key_size => 2048,
       },
       commands => {
-         ca_init => [ qw(name|OPTIONAL directory|OPTIONAL) ],
-         set_ca_attributes => [ qw(name|OPTIONAL) ],
-         ca_show => [ qw(name|OPTIONAL) ],
-         ca_sign_csr => [ qw(csr_file|OPTIONAL name|OPTIONAL) ],
+         ca_init => [ qw(name directory|OPTIONAL) ],
+         set_ca_attributes => [ qw(name) ],
+         ca_show => [ qw(name) ],
+         ca_sign_csr => [ qw(name csr_file) ],
          csr_new => [ qw(base_file use_passphrase|OPTIONAL) ],
          cert_hash => [ qw(cert_file) ],
-         cert_verify => [ qw(cert_file name|OPTIONAL) ],
+         cert_verify => [ qw(name cert_file) ],
       },
       require_modules => {
          'Metabrik::File::Text' => [ ],
@@ -53,8 +49,9 @@ sub set_ca_attributes {
    my $self = shift;
    my ($name) = @_;
 
-   $name ||= $self->ca_name;
-   $self->brik_help_run_undef_arg('set_ca_attributes', $name) or return;
+   if (! defined($name)) {
+      return $self->log->error($self->brik_help_run('set_ca_attributes'));
+   }
 
    my $ca_lc_name = lc($name);
    my $ca_directory = $self->datadir.'/'.$ca_lc_name;
@@ -79,8 +76,9 @@ sub ca_init {
    my $self = shift;
    my ($name, $directory) = @_;
 
-   $name ||= $self->ca_name;
-   $self->brik_help_run_undef_arg('ca_init', $name) or return;
+   if (! defined($name)) {
+      return $self->log->error($self->brik_help_run('ca_init'));
+   }
 
    $self->set_ca_attributes($name)
       or return $self->log->error("ca_init: set_ca_attributes failed");
@@ -94,11 +92,12 @@ sub ca_init {
          or return $self->log->error("ca_init: mkdir failed with error [$!]");
       mkdir($ca_directory.'/certs');
 
-      my $ft = Metabrik::File::Text->new_from_brik_init($self) or return;
-      $ft->write('', $ca_directory.'/index.txt')
+      my $index_txt = Metabrik::File::Text->new_from_brik($self) or return;
+      $index_txt->write('', $ca_directory.'/index.txt')
          or return $self->log->error("ca_init: write index.txt failed");
 
-      $ft->write('01', $ca_directory.'/serial')
+      my $serial = Metabrik::File::Text->new_from_brik($self) or return;
+      $serial->write('01', $ca_directory.'/serial')
          or return $self->log->error("ca_init: write serial failed");
    }
 
@@ -108,7 +107,6 @@ sub ca_init {
    my $ca_cert = $self->ca_cert;
    my $ca_key = $self->ca_key;
    my $ca_lc_name = $self->ca_lc_name;
-   my $key_size = $self->key_size;
 
    my $email = 'dummy@example.com';
    my $organization = 'Dummy Org';
@@ -144,7 +142,7 @@ sub ca_init {
       "basicConstraints = CA:false",
       "",
       "[ req ]",
-      "default_bits       = $key_size",
+      "default_bits       = 2048",
       "default_keyfile    = $ca_key",
       "#default_md         = md5",
       "default_days       = 1800",
@@ -164,14 +162,14 @@ sub ca_init {
       "basicConstraints = CA:true",
    ];
 
-   my $ft = Metabrik::File::Text->new_from_brik_init($self) or return;
-   $ft->overwrite(1);
-   $ft->write($content, $ca_conf)
+   my $file_text = Metabrik::File::Text->new_from_brik($self) or return;
+   $file_text->overwrite(1);
+   $file_text->write($content, $ca_conf)
       or return $self->log->error("ca_init: write failed");
 
    $self->log->verbose("ca_init: using conf file [$ca_conf] and cert [$ca_cert]");
 
-   my $cmd = "openssl req -x509 -newkey rsa:$key_size ".
+   my $cmd = "openssl req -x509 -newkey rsa:1024 ".
              "-days 1800 -out $ca_cert -outform PEM -config $ca_conf";
 
    return $self->capture($cmd);
@@ -181,8 +179,9 @@ sub ca_show {
    my $self = shift;
    my ($name) = @_;
 
-   $name ||= $self->ca_name;
-   $self->brik_help_run_undef_arg('ca_show', $name) or return;
+   if (! defined($name)) {
+      return $self->log->error($self->brik_help_run('ca_show'));
+   }
 
    $self->set_ca_attributes($name) or return;
 
@@ -195,19 +194,21 @@ sub csr_new {
    my $self = shift;
    my ($base_file, $use_passphrase) = @_;
 
+   if (! defined($base_file)) {
+      return $self->log->error($self->brik_help_run('csr_new'));
+   }
+
    $use_passphrase ||= $self->use_passphrase;
-   $self->brik_help_run_undef_arg('csr_new', $base_file) or return;
 
    my $datadir = $self->datadir;
    my $csr_cert = $datadir.'/'.$base_file.'.pem';
    my $csr_key = $datadir.'/'.$base_file.'.key';
-   my $key_size = $self->key_size;
 
    if (-f $csr_cert) {
       return $self->log->error("csr_new: file [$csr_cert] already exists");
    }
 
-   my $cmd = "openssl req -newkey rsa:$key_size -keyout $csr_key -keyform PEM ".
+   my $cmd = "openssl req -newkey rsa:1024 -keyout $csr_key -keyform PEM ".
              "-out $csr_cert -outform PEM";
 
    if (! $use_passphrase) {
@@ -224,12 +225,18 @@ sub csr_new {
 
 sub ca_sign_csr {
    my $self = shift;
-   my ($csr_cert, $name) = @_;
+   my ($name, $csr_cert) = @_;
 
-   $name ||= $self->ca_name;
-   $self->brik_help_run_undef_arg('ca_sign_csr', $csr_cert) or return;
-   $self->brik_help_run_file_not_found('ca_sign_csr', $csr_cert) or return;
-   $self->brik_help_run_undef_arg('ca_sign_csr', $name) or return;
+   if (! defined($name)) {
+      return $self->log->error($self->brik_help_run('ca_sign_csr'));
+   }
+   if (! defined($csr_cert)) {
+      return $self->log->error($self->brik_help_run('ca_sign_csr'));
+   }
+
+   if (! -f $csr_cert) {
+      return $self->log->error("ca_sign_csr: file [$csr_cert] does not exists");
+   }
 
    $self->set_ca_attributes($name) or return;
 
@@ -255,8 +262,13 @@ sub cert_hash {
    my $self = shift;
    my ($cert_file) = @_;
 
-   $self->brik_help_run_undef_arg('cert_hash', $cert_file) or return;
-   $self->brik_help_run_file_not_found('cert_hash', $cert_file) or return;
+   if (! defined($cert_file)) {
+      return $self->log->error($self->brik_help_run('cert_hash'));
+   }
+
+   if (! -f $cert_file) {
+      return $self->log->error("cert_hash: file [$cert_file] not found");
+   }
 
    my $cmd = "openssl x509 -noout -hash -in $cert_file";
 
@@ -265,12 +277,18 @@ sub cert_hash {
 
 sub cert_verify {
    my $self = shift;
-   my ($cert_file, $name) = @_;
+   my ($name, $cert_file) = @_;
 
-   $name ||= $self->ca_name;
-   $self->brik_help_run_undef_arg('cert_verify', $cert_file) or return;
-   $self->brik_help_run_file_not_found('cert_verify', $cert_file) or return;
-   $self->brik_help_run_undef_arg('cert_verify', $name) or return;
+   if (! defined($name)) {
+      return $self->log->error($self->brik_help_run('cert_verify'));
+   }
+   if (! defined($cert_file)) {
+      return $self->log->error($self->brik_help_run('cert_verify'));
+   }
+
+   if (! -f $cert_file) {
+      return $self->log->error("cert_verify: file [$cert_file] not found");
+   }
 
    $self->set_ca_attributes($name) or return;
 
@@ -291,7 +309,7 @@ Metabrik::Crypto::X509 - crypto::x509 Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
