@@ -1,5 +1,5 @@
 #
-# $Id: Nvd.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Nvd.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
 #
 # database::nvd Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::File::Fetch);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: 1db92d72d9a2 $',
       tags => [ qw(unstable cve cpe nvd nist) ],
       attributes => {
          datadir => [ qw(datadir) ],
@@ -35,27 +35,6 @@ sub brik_properties {
    };
 }
 
-sub brik_use_properties {
-   my $self = shift;
-
-   return {
-      attributes_default => {
-         datadir => $self->global->datadir.'/nvd',
-      },
-   };
-}
-
-sub brik_init {
-   my $self = shift;
-
-   my $datadir = $self->datadir;
-   if (! -d $datadir) {
-      mkdir($datadir);
-   }
-
-   return $self->SUPER::brik_init(@_);
-}
-
 # http://nvd.nist.gov/download.cfm
 # nvdcve-2.0-Modified.xml.gz includes all recently published and recently updated vulnerabilities.
 # nvdcve-2.0-Recent.xml.gz includes all recently published vulnerabilities.
@@ -89,7 +68,7 @@ sub update {
 
    my $datadir = $self->datadir;
 
-   my $compress = Metabrik::File::Compress->new_from_brik($self);
+   my $compress = Metabrik::File::Compress->new_from_brik($self) or return;
 
    if ($type eq 'recent') {
       (my $uri = $resource->{uri}) =~ s/NAME/Recent/;
@@ -178,7 +157,7 @@ sub load {
 
    my $datadir = $self->datadir;
 
-   my $brik_xml = Metabrik::File::Xml->new_from_brik($self);
+   my $brik_xml = Metabrik::File::Xml->new_from_brik($self) or return;
 
    my $old = $self->loaded_xml;
 
