@@ -1,5 +1,5 @@
 #
-# $Id: Compress.pm,v 14a5b315905e 2015/01/08 07:00:53 gomor $
+# $Id: Compress.pm,v 297f479a9ee8 2015/02/11 06:55:12 gomor $
 #
 # file::zip brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 14a5b315905e $',
+      revision => '$Revision: 297f479a9ee8 $',
       tags => [ qw(unstable compress unzip gunzip uncompress) ],
       attributes => {
          datadir => [ qw(directory) ],
@@ -42,7 +42,9 @@ sub unzip {
 
    my $cmd = "unzip -o $input -d $datadir/";
 
-   return $self->system($cmd);
+   $self->system($cmd) or return;
+
+   return $datadir;
 }
 
 sub gunzip {
@@ -64,7 +66,9 @@ sub gunzip {
 
    my $cmd = "gunzip -c $input > $file_out";
 
-   return $self->system($cmd);
+   $self->system($cmd) or return;
+
+   return $file_out;
 }
 
 1;
