@@ -1,5 +1,5 @@
 #
-# $Id: Csv.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Csv.pm,v ebfd97b93de6 2015/01/22 07:05:08 gomor $
 #
 # file::csv Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: ebfd97b93de6 $',
       tags => [ qw(unstable csv file) ],
       attributes => {
          input => [ qw(file) ],
@@ -102,7 +102,8 @@ sub read {
 
    if (! $csv->eof) {
       my $error_str = "".$csv->error_diag();
-      return $self->log->error("read: $error_str");
+      $self->log->error("read: incomplete: error [$error_str]");
+      return \@rows;
    }
 
    $read->close;
