@@ -1,5 +1,5 @@
 #
-# $Id: Write.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Write.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
 #
 # file::write Brik
 #
@@ -11,10 +11,8 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
-      tags => [ qw(unstable) ],
-      author => 'GomoR <GomoR[at]metabrik.org>',
-      license => 'http://opensource.org/licenses/BSD-3-Clause',
+      revision => '$Revision: 1db92d72d9a2 $',
+      tags => [ qw(unstable file) ],
       attributes => {
          output => [ qw(file) ],
          append => [ qw(0|1) ],
@@ -42,6 +40,7 @@ sub brik_use_properties {
    # encoding: see `perldoc Encode::Supported' for other types
    return {
       attributes_default => {
+         output => $self->global->output || '/tmp/output.txt',
          encoding => $self->global->encoding || 'utf8',
       },
    };
@@ -52,7 +51,9 @@ sub open {
    my ($output) = @_;
 
    $output ||= $self->output;
-   $self->brik_help_run_undef_arg('open', $output) or return;
+   if (! defined($output)) {
+      return $self->log->error($self->brik_help_set('output'));
+   }
 
    my $encoding = $self->encoding;
    if ($encoding eq 'ascii') {
@@ -84,8 +85,6 @@ sub open {
       select($previous_default);          
    }
 
-   $self->debug && $self->log->debug("open: fd [$out]");
-
    return $self->fd($out);
 }
 
@@ -104,12 +103,17 @@ sub write {
    my $self = shift;
    my ($data) = @_;
 
-   my $fd = $self->fd;
-   $self->brik_help_run_undef_arg('open', $fd) or return;
-   $self->brik_help_run_undef_arg('write', $data) or return;
+   if (! defined($data)) {
+      return $self->log->error($self->brik_help_run('write'));
+   }
 
    $self->debug && $self->log->debug("write: data[$data]");
 
+   my $fd = $self->fd;
+   if (! defined($fd)) {
+      return $self->log->error($self->brik_help_run('open'));
+   }
+
    if (ref($data) eq 'ARRAY') {
       for my $this (@$data) {
          print $fd $this."\n";
@@ -132,7 +136,7 @@ Metabrik::File::Write - file::write Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
