@@ -1,5 +1,5 @@
 #
-# $Id: Service.pm,v f0806c23ff74 2015/01/25 18:03:03 gomor $
+# $Id: Service.pm,v e9efd64d88ce 2015/02/26 06:10:35 gomor $
 #
 # lookup::service Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::File::Csv);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f0806c23ff74 $',
+      revision => '$Revision: e9efd64d88ce $',
       tags => [ qw(unstable lookup service iana) ],
       attributes => {
          datadir => [ qw(datadir) ],
@@ -87,7 +87,7 @@ sub from_dec {
    }
 
    # No match
-   return;
+   return 'unknown';
 }
 
 sub from_hex {
@@ -124,10 +124,6 @@ sub from_string {
          $self->log->verbose("from_string: match with [$service]");
          push @match, $this->{'Port Number'}.'/'.$this->{'Transport Protocol'};
       }
-      elsif ($service =~ /$string/i) {
-         $self->log->verbose("from_string: match with [$service]");
-         push @match, $this->{'Port Number'}.'/'.$this->{'Transport Protocol'};
-      }
    }
 
    return \@match;
