@@ -1,5 +1,5 @@
 #
-# $Id: Nmap.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Nmap.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
 #
 # network::nmap Brik
 #
@@ -11,9 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: 1db92d72d9a2 $',
       tags => [ qw(unstable network security scanner nmap) ],
       attributes => {
+         datadir => [ qw(datadir) ],
          targets => [ qw(nmap_targets) ],
          ports => [ qw(nmap_ports) ],
          args => [ qw(nmap_args) ],
@@ -95,7 +96,7 @@ sub tcp_syn {
    my $service_scan = $self->service_scan;
    my $save_output = $self->save_output;
 
-   my $datadir = $self->global->datadir;
+   my $datadir = $self->datadir;
 
    my $cmd = "sudo nmap -v -sS --max-retries $max_retries --min-rate $rate --max-rate $rate $args";
    if ($service_scan) {
@@ -126,7 +127,7 @@ sub tcp_connect {
    my $service_scan = $self->service_scan;
    my $save_output = $self->save_output;
 
-   my $datadir = $self->global->datadir;
+   my $datadir = $self->datadir;
  
    my $cmd = "sudo nmap -v -sT --max-retries $max_retries --min-rate $rate --max-rate $rate $args";
    if ($service_scan) {
@@ -155,7 +156,7 @@ sub udp {
    my $service_scan = $self->service_scan;
    my $save_output = $self->save_output;
 
-   my $datadir = $self->global->datadir;
+   my $datadir = $self->datadir;
 
    my $cmd = "sudo nmap -v -sU --max-retries $max_retries --min-rate $rate --max-rate $rate $args";
    if ($service_scan) {
