@@ -1,5 +1,5 @@
 #
-# $Id: Sqlmap.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Sqlmap.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
 #
 # network::sqlmap Brik
 #
@@ -11,30 +11,24 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: 1db92d72d9a2 $',
       tags => [ qw(unstable network security scanner sqlmap sql injection) ],
       attributes => {
+         datadir => [ qw(datadir) ],
          cookie => [ qw(string) ],
          parameter => [ qw(parameter_name) ],
          request_file => [ qw(file) ],
          args => [ qw(sqlmap_arguments) ],
          output_file => [ qw(file) ],
       },
-      commands => {
-         start => [ ],
-      },
-   };
-}
-
-sub brik_use_properties {
-   my $self = shift;
-
-   return {
       attributes_default => {
-         request_file => $self->global->datadir.'/sqlmap_request.txt',
+         request_file => 'sqlmap_request.txt',
          parameter => 'parameter',
          args => '--ignore-proxy -v 3 --level=5 --risk=3 --user-agent "Mozilla"',
       },
+      commands => {
+         start => [ ],
+      },
    };
 }
 
@@ -42,11 +36,12 @@ sub brik_use_properties {
 sub start {
    my $self = shift;
 
+   my $datadir = $self->datadir;
    my $args = $self->args;
    my $cookie = $self->cookie;
    my $parameter = $self->parameter;
-   my $request_file = $self->request_file;
-   my $output_file = $self->output_file;
+   my $request_file = $datadir.'/'.$self->request_file;
+   my $output_file = $datadir.'/'.$self->output_file;
 
    if (! -f $request_file) {
       return $self->log->error("start: request file [$request_file] not found");
