@@ -1,5 +1,5 @@
 #
-# $Id: Parse.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Parse.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
 #
 # string::parse Brik
 #
@@ -11,12 +11,12 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: 1db92d72d9a2 $',
       tags => [ qw(unstable parse string) ],
       commands => {
          identify => [ qw(string) ],
-         to_array => [ qw(0|1) ],
-         to_matrix => [ qw(0|1) ],
+         to_array => [ qw($data) ],
+         to_matrix => [ qw($data) ],
       },
    };
 }
