@@ -1,5 +1,5 @@
 #
-# $Id: Random.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Random.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
 #
 # string::random Brik
 #
@@ -11,23 +11,26 @@ use base qw(Metabrik::String::Password);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: 1db92d72d9a2 $',
       tags => [ qw(unstable string random) ],
       attributes_default => {
+         datadir => [ qw(datadir) ],
          charset => [ 'A'..'K', 'M'..'Z', 'a'..'k', 'm'..'z', 2..9, '_', '-' ],
          length => 20,
          count => 1,
       },
       commands => {
-         filename => [ ],
+         filename => [ qw(datadir|OPTIONAL) ],
       },
    };
 }
 
 sub filename {
    my $self = shift;
+   my ($datadir) = @_;
+
+   $datadir ||= $self->datadir;
 
-   my $datadir = $self->global->datadir;
    my $random = $self->generate;
 
    return "$datadir/".$random->[0];
