@@ -1,5 +1,5 @@
 #
-# $Id: Xml.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Xml.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
 #
 # string::xml Brik
 #
@@ -7,25 +7,19 @@ package Metabrik::String::Xml;
 use strict;
 use warnings;
 
-use base qw(Metabrik::System::Package);
+use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
-      tags => [ qw(unstable encode decode) ],
-      author => 'GomoR <GomoR[at]metabrik.org>',
-      license => 'http://opensource.org/licenses/BSD-3-Clause',
+      revision => '$Revision: 1db92d72d9a2 $',
+      tags => [ qw(unstable encode decode xml) ],
       commands => {
-         install => [ ], # Inherited
          encode => [ qw($data_hash) ],
          decode => [ qw($data) ],
       },
       require_modules => {
          'XML::Simple' => [ ],
       },
-      need_packages => {
-         'ubuntu' => [ qw(libexpat1-dev libxml2-dev) ],
-      },
    };
 }
 
@@ -33,8 +27,13 @@ sub encode {
    my $self = shift;
    my ($data) = @_;
 
-   $self->brik_help_run_undef_arg('encode', $data) or return;
-   $self->brik_help_run_invalid_arg('encode', $data, 'HASH') or return;
+   if (! defined($data)) {
+      return $self->log->error($self->brik_help_run('encode'));
+   }
+
+   if (ref($data) ne 'HASH') {
+      return $self->log->error("encode: you need to give data as HASHREF");
+   }
 
    my $xs = XML::Simple->new;
 
@@ -45,7 +44,9 @@ sub decode {
    my $self = shift;
    my ($data) = @_;
 
-   $self->brik_help_run_undef_arg('decode', $data) or return;
+   if (! defined($data)) {
+      return $self->log->error($self->brik_help_run('decode'));
+   }
 
    my $xs = XML::Simple->new;
 
@@ -62,7 +63,7 @@ Metabrik::String::Xml - string::xml Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
