@@ -1,5 +1,5 @@
 #
-# $Id: Os.pm,v f86a021f7e5f 2015/01/24 17:03:49 gomor $
+# $Id: Os.pm,v 39f1159c4a8c 2015/02/17 06:45:33 gomor $
 #
 # system::os brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f86a021f7e5f $',
+      revision => '$Revision: 39f1159c4a8c $',
       tags => [ qw(unstable os uname linux freebsd distribution) ],
       attributes => {
          _uname => [ qw(INTERNAL) ],
@@ -105,6 +105,7 @@ sub distribution {
    if ($name eq 'Linux') {
       my $ft = Metabrik::File::Text->new_from_brik($self) or return;
       $ft->as_array(1);
+      $ft->strip_crlf(1);
 
       # Ubuntu case
       if (-f '/etc/lsb-release') {
@@ -117,6 +118,9 @@ sub distribution {
             $info{$k} = $v;
          }
 
+         $info{DISTRIB_DESCRIPTION} =~ s/^"//;
+         $info{DISTRIB_DESCRIPTION} =~ s/"$//;
+
          return {
             name => $info{DISTRIB_ID},                 # Ubuntu
             release => $info{DISTRIB_RELEASE},         # 14.10
